@@ -57,10 +57,6 @@
 #include "MButton.h"
 #include "Vlist.h"
 
-#ifdef VMS
-#   include <unixio.h>
-#endif
-
 #include "types.h"
 #include "actions.h"
 #include "callbacks.h"
@@ -98,7 +94,7 @@ action_shellConfigureNotify(w, event, params, num_params)
   }
   if (new_width && new_height) {
     if (width != new_width || height != new_height) {
-       misc_setPageMarker(0,2); /* bring selected in sight */
+       misc_setPageMarker(0,2,event,True); /* bring selected in sight */
        width = new_width;
        height=new_height;
     }
@@ -151,7 +147,7 @@ action_page(w, event, params, num_params)
   int i;
   char *s;
   static String *old_params = NULL;
-  static old_num_params = 0;
+  static int old_num_params = 0;
   String *pars;
   int    npars;
   static XtIntervalId timer = 0;
@@ -257,7 +253,7 @@ action_page(w, event, params, num_params)
 	}
       }
       h = doc_putPageInRange(doc,h);
-      misc_setPageMarker(h,1);
+      misc_setPageMarker(h,1,event,False);
     }
 
     nx = x = (int)aaa->core.x;
@@ -270,7 +266,7 @@ action_page(w, event, params, num_params)
     if (a & (PAGE_LEFT|PAGE_RIGHT)) {
       d = (int)aaa->core.width-cw;
       if (d > 0) {
-	INFMESSAGE(scrolling left or right)
+	/* scrolling left or right */
 	f = (dc*(float)d)/(float)cw;
         if (f<1) f = 1;
         d = (int)(((f/(float)abs((int)f))*(float)cw)/dc+1.0);
@@ -281,7 +277,7 @@ action_page(w, event, params, num_params)
     if (a & (PAGE_UP|PAGE_DOWN)) {
        d = (int)aaa->core.height - ch;
        if (d>0) {
-	 INFMESSAGE(scrolling up or down)
+	 /* scrolling up or down */
 	 f = (dc*(float)d)/(float)ch;
 	 if (f<1) f = 1;
 	 d = (int)(((f/(float)abs((int)f))*(float)ch)/dc+1.0);
@@ -432,7 +428,7 @@ action_toc(w, event, params, num_params)
     if (!scrolling && toc_text) {
       entry = VlistEntryOfPosition(newtoc,(int)event->xbutton.y);
       if (entry >=0 && entry < doc->numpages) {
-	misc_setPageMarker(entry,0);
+	misc_setPageMarker(entry,0,event,True);
         show_page(entry,NULL);
       }
     }
