@@ -99,7 +99,6 @@
 #include "resource.h"
 #include "doc_misc.h"
 #include "version.h"
-#include "stdc.h"
 #include "scale.h"
 
 #if defined(USE_SIGNAL_HANDLER) && (XtSpecificationRelease < 6)
@@ -109,12 +108,12 @@
 #   include "gv_signal.h"
 #endif /* USE_SIGNAL_HANDLER */
 
-
+#define BITSOF(name) name ## _bits
+#define WIDTHOF(name) name ## _height
+#define HEIGHTOF(name) name ## _width
 #define BITMAP_ARGS(name)\
-           (const char*)CONCAT(name,_bits),\
-           CONCAT(name,_width),\
-           CONCAT(name,_height)
- 
+           (const char*)BITSOF(name), WIDTHOF(name), HEIGHTOF(name)
+
 #include FALLBACK_ICON_PIXMAP
 #include FALLBACK_SELECTED_BITMAP
 #include FALLBACK_DOCUMENT_BITMAP
@@ -589,13 +588,10 @@ int main(argc, argv)
      }
 
    /*### getting resources ############################################*/
-   gv_database = resource_buildDatabase (XtDatabase(gv_display),
-                                         gv_display,
+   gv_database = resource_buildDatabase (gv_display,
                                          gv_class,
                                          gv_name,
                                          &argc,argv);
-   XrmSetDatabase (gv_display, gv_database);
-
 
 /*### initializing widget set and creating application shell #########################*/
 
@@ -1033,7 +1029,8 @@ int main(argc, argv)
             XtSetArg(args[n], XtNinterpreter,gv_gs_interpreter);	n++;
             b = gv_gs_safer ? True : False;
             XtSetArg(args[n], XtNsafer,b);                              n++;
-            XtSetArg(args[n], XtNquiet, True);                          n++;
+            b = gv_gs_quiet ? True : False;
+            XtSetArg(args[n], XtNquiet,b);                              n++;
             b = app_res.use_bpixmap ? True : False;
             XtSetArg(args[n], XtNuseBackingPixmap,b);                   n++;
             XtSetArg(args[n], XtNarguments,gv_gs_arguments);            n++;
