@@ -464,6 +464,7 @@ unc_ok:
       doc = (struct document *) PS_malloc(sizeof(struct document));
       CHECK_MALLOCED(doc);
       memset(doc, 0, sizeof(struct document));
+      *text=0;
       sscanf(line, "%*s %256s", text);
       /*###jp###*/
       /*doc->epsf = iscomment(text, "EPSF-");*/
@@ -1738,6 +1739,7 @@ static char * readline (fd, lineP, positionP, line_lenP)
 {
    unsigned int nbytes=0;
    int skipped=0;
+   int nesting_level=0;
    char *line;
 
    BEGINMESSAGE(readline)
@@ -1796,7 +1798,15 @@ static char * readline (fd, lineP, positionP, line_lenP)
 #endif
    if  (!IS_COMMENT("Begin"))     {} /* Do nothing */
    else if IS_BEGIN("Document:")  {  /* Skip the EPS without handling its content */
-            while (line && !IS_END("Document")) {
+            nesting_level=1;
+            line = ps_io_fgetchars(fd,-1);
+            if (line) *line_lenP += FD_LINE_LEN;
+            while (line) {
+               if (IS_COMMENT("Begin") && IS_BEGIN("Document:"))
+		 nesting_level++;
+               else if (IS_COMMENT("End") && IS_END("Document"))
+		 nesting_level--;
+               if (nesting_level == 0) break;
                line = ps_io_fgetchars(fd,-1);
                if (line) *line_lenP += FD_LINE_LEN;
             }
